==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/datadog/kotlin/inputs/SubscriptionListArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datadog.kotlin.inputs

import com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs.builder
import com.pulumi.azurenative.datadog.kotlin.enums.Operation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The request to update subscriptions needed to be monitored by the Datadog monitor resource.
 * @property monitoredSubscriptionList List of subscriptions and the state of the monitoring.
 * @property operation The operation for the patch on the resource.
 */
public data class SubscriptionListArgs(
    public val monitoredSubscriptionList: Output<List<MonitoredSubscriptionArgs>>? = null,
    public val operation: Output<Either<String, Operation>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs> {
    override fun toJava(): com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs =
        com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs.builder()
            .monitoredSubscriptionList(
                monitoredSubscriptionList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .operation(
                operation?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [SubscriptionListArgs].
 */
@PulumiTagMarker
public class SubscriptionListArgsBuilder internal constructor() {
    private var monitoredSubscriptionList: Output<List<MonitoredSubscriptionArgs>>? = null

    private var operation: Output<Either<String, Operation>>? = null

    /**
     * @param value List of subscriptions and the state of the monitoring.
     */
    @JvmName("enxryhpqoqgfihnh")
    public suspend fun monitoredSubscriptionList(`value`: Output<List<MonitoredSubscriptionArgs>>) {
        this.monitoredSubscriptionList = value
    }

    @JvmName("wlnveahtmaisltbr")
    public suspend fun monitoredSubscriptionList(vararg values: Output<MonitoredSubscriptionArgs>) {
        this.monitoredSubscriptionList = Output.all(values.asList())
    }

    /**
     * @param values List of subscriptions and the state of the monitoring.
     */
    @JvmName("bbabmpymybkgkisk")
    public suspend fun monitoredSubscriptionList(values: List<Output<MonitoredSubscriptionArgs>>) {
        this.monitoredSubscriptionList = Output.all(values)
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("synydyckbaeawjxb")
    public suspend fun operation(`value`: Output<Either<String, Operation>>) {
        this.operation = value
    }

    /**
     * @param value List of subscriptions and the state of the monitoring.
     */
    @JvmName("nveilhlqudgpsfxx")
    public suspend fun monitoredSubscriptionList(`value`: List<MonitoredSubscriptionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param argument List of subscriptions and the state of the monitoring.
     */
    @JvmName("keiwgfwhavktbyus")
    public suspend
    fun monitoredSubscriptionList(argument: List<suspend MonitoredSubscriptionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MonitoredSubscriptionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param argument List of subscriptions and the state of the monitoring.
     */
    @JvmName("vniapqyhvxiglgrh")
    public suspend fun monitoredSubscriptionList(
        vararg
        argument: suspend MonitoredSubscriptionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MonitoredSubscriptionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param argument List of subscriptions and the state of the monitoring.
     */
    @JvmName("wxexgvbacqhsdphe")
    public suspend
    fun monitoredSubscriptionList(argument: suspend MonitoredSubscriptionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MonitoredSubscriptionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param values List of subscriptions and the state of the monitoring.
     */
    @JvmName("iyqyiugjjutgaoui")
    public suspend fun monitoredSubscriptionList(vararg values: MonitoredSubscriptionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("ocxacumfcxnulqes")
    public suspend fun operation(`value`: Either<String, Operation>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("mvrgyfhluhtdpemn")
    public fun operation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Operation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("luygtvatmmcgvfye")
    public fun operation(`value`: Operation) {
        val toBeMapped = Either.ofRight<String, Operation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    internal fun build(): SubscriptionListArgs = SubscriptionListArgs(
        monitoredSubscriptionList = monitoredSubscriptionList,
        operation = operation,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datadog/kotlin/inputs/SubscriptionListArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datadog.kotlin.inputs

import com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs.builder
import com.pulumi.azurenative.datadog.kotlin.enums.Operation
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The request to update subscriptions needed to be monitored by the Datadog monitor resource.
 * @property monitoredSubscriptionList List of subscriptions and the state of the monitoring.
 * @property operation The operation for the patch on the resource.
 */
public data class SubscriptionListArgs(
    public val monitoredSubscriptionList: Output<List<MonitoredSubscriptionArgs>>? = null,
    public val operation: Output<Either<String, Operation>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs> {
    override fun toJava(): com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs =
        com.pulumi.azurenative.datadog.inputs.SubscriptionListArgs.builder()
            .monitoredSubscriptionList(
                monitoredSubscriptionList?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .operation(
                operation?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [SubscriptionListArgs].
 */
@PulumiTagMarker
public class SubscriptionListArgsBuilder internal constructor() {
    private var monitoredSubscriptionList: Output<List<MonitoredSubscriptionArgs>>? = null

    private var operation: Output<Either<String, Operation>>? = null

    /**
     * @param value List of subscriptions and the state of the monitoring.
     */
    @JvmName("nnvpohnyixotxdqm")
    public suspend fun monitoredSubscriptionList(`value`: Output<List<MonitoredSubscriptionArgs>>) {
        this.monitoredSubscriptionList = value
    }

    @JvmName("nxammjgbwjnkrtfp")
    public suspend fun monitoredSubscriptionList(vararg values: Output<MonitoredSubscriptionArgs>) {
        this.monitoredSubscriptionList = Output.all(values.asList())
    }

    /**
     * @param values List of subscriptions and the state of the monitoring.
     */
    @JvmName("jrhydfnwbynmdpiq")
    public suspend fun monitoredSubscriptionList(values: List<Output<MonitoredSubscriptionArgs>>) {
        this.monitoredSubscriptionList = Output.all(values)
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("ebkiphyclbdkgmpi")
    public suspend fun operation(`value`: Output<Either<String, Operation>>) {
        this.operation = value
    }

    /**
     * @param value List of subscriptions and the state of the monitoring.
     */
    @JvmName("hnjdqruplbedeblv")
    public suspend fun monitoredSubscriptionList(`value`: List<MonitoredSubscriptionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param argument List of subscriptions and the state of the monitoring.
     */
    @JvmName("luqpecvyvvfngxsx")
    public suspend
    fun monitoredSubscriptionList(argument: List<suspend MonitoredSubscriptionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            MonitoredSubscriptionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param argument List of subscriptions and the state of the monitoring.
     */
    @JvmName("qialpsfsbylvsgre")
    public suspend fun monitoredSubscriptionList(
        vararg
        argument: suspend MonitoredSubscriptionArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            MonitoredSubscriptionArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param argument List of subscriptions and the state of the monitoring.
     */
    @JvmName("ygjxwdmovxclcynk")
    public suspend
    fun monitoredSubscriptionList(argument: suspend MonitoredSubscriptionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(MonitoredSubscriptionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param values List of subscriptions and the state of the monitoring.
     */
    @JvmName("eowgwlqsiiwphmqm")
    public suspend fun monitoredSubscriptionList(vararg values: MonitoredSubscriptionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monitoredSubscriptionList = mapped
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("bnbochtpqehtjuao")
    public suspend fun operation(`value`: Either<String, Operation>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("xucrtojwhvygdqin")
    public fun operation(`value`: String) {
        val toBeMapped = Either.ofLeft<String, Operation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    /**
     * @param value The operation for the patch on the resource.
     */
    @JvmName("ekhylkkppidnywfc")
    public fun operation(`value`: Operation) {
        val toBeMapped = Either.ofRight<String, Operation>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operation = mapped
    }

    internal fun build(): SubscriptionListArgs = SubscriptionListArgs(
        monitoredSubscriptionList = monitoredSubscriptionList,
        operation = operation,
    )
}
